@@ -6,8 +6,9 @@ import unittest
 from uuid import UUID
 
 from preseem import NetworkMetadataReference, FakePreseemModel
-from preseem.source_model import Account, Service
+from preseem.source_model import Account, Service, Attachment
 from preseem_protobuf.model.account_pb2 import AccountStatus
+from preseem_protobuf.model.service_pb2 import SetAttachmentReq
 
 sys.path.append(os.path.dirname(__file__))  # let code under test load stubs
 from fake_context import FakeContext
@@ -134,3 +135,47 @@ class TestServiceSync(unittest.TestCase):
         self.assertEqual(s.download_rate, 90000)
         self.assertEqual(s.upload_rate, 18000)
         self.assertEqual(s.attachment.username, service.attachment.username)
+
+    def test_ignore_service_attachment_field(self):
+        """A service field can be ignored by configuration."""
+        self._task = self.loop.create_task(self.service_syncer.run())
+        self._await(asyncio.sleep(0)) # yield eventloop so it can start
+
+        self.ctx.model_sync_config = {"service": {"attachment": {"cpe_mac_address": {"ignore": True}}}}
+        account = Account(id='a100', name='Account 100', status=AccountStatus.ACCOUNT_STATUS_ACTIVE)
+        service = Service(id='s100', account_id='a100', subscriber_identifier='a100.s100')
+        service.download_rate = 100000
+        service.upload_rate = 20000
+        service.attachment.username = 's100'
+        self._await(self.service_syncer.set('router.1', [account], [service]))
+        self._await(asyncio.sleep(2)) # let the syncer run past its holdoff
+
+        account_ref = NetworkMetadataReference(type='account', value='a100', attributes={'subscriber_identifier': 'a100', 'subscriber_name': 'Account 100', 'system': 'net'})
+        service_ref = NetworkMetadataReference(type='service', value='s100', attributes={'account': 'a100', 'system': 'net', 'service_rate_down': 100000, 'service_rate_up': 20000, 'username': 's100'})
+        account_refs = self.ctx.netmeta_model.refs.get('account') or {}
+        service_refs = self.ctx.netmeta_model.refs.get('service') or {}
+        self.assertEqual(account_refs.get('a100'), account_ref)
+        self.assertEqual(service_refs.get('s100'), service_ref)
+        services = self._await(self.ctx.preseem_model.Service.List(company_uuid=self.company.uuid))
+        self.assertEqual(len(services), 1)
+        s = next(iter(x for x in services if x.source_id == service.id), None)
+        self.assertEqual(s.download_rate, 100000)
+        self.assertEqual(s.upload_rate, 20000)
+        self.assertEqual(s.attachment.username, service.attachment.username)
+
+        # Something else sets the CPE MAC address of the service attachment.
+        set_att_req = SetAttachmentReq()
+        set_att_req.attachment.CopyFrom(s.attachment)
+        set_att_req.attachment.cpe_mac_address = "00:01:00:01:00:01"
+        s = self._await(self.ctx.preseem_model.Service.Update(company_uuid=self.company.uuid, uuid=s.uuid, attachment_req=set_att_req))
+
+        self._await(self.service_syncer.set('router.1', [account], [service]))
+        self._await(asyncio.sleep(2)) # let the syncer run past its holdoff
+
+        services = self._await(self.ctx.preseem_model.Service.List(company_uuid=self.company.uuid))
+        self.assertEqual(len(services), 1)
+        s = next(iter(x for x in services if x.source_id == service.id), None)
+        self.assertEqual(s.download_rate, 100000)
+        self.assertEqual(s.upload_rate, 20000)
+        self.assertEqual(s.attachment.username, service.attachment.username)
+        self.assertEqual(s.attachment.cpe_mac_address,  "00:01:00:01:00:01")
